@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 1;
 
@@ -63,6 +63,10 @@ Perl class for reading/writing DCMTK dcmqrscp configuration file.
 
 Detect DICOM file through magic string.
 
+=item L<Dicom::UID::Generator>
+
+DICOM UID generator.
+
 =item L<File::Find::Rule::Dicom>
 
 Common rules for searching for DICOM things.
@@ -71,7 +75,7 @@ Common rules for searching for DICOM things.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Task-Lego>
+L<https://github.com/tupinek/Task-Dicom>
 
 =head1 AUTHOR
 
@@ -81,11 +85,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015 Michal Špaček
+ © 2015-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
